@@ -1,12 +1,11 @@
 ###############################################################################
 #
-#   (c) Copyright @ 2000, Randy J. Ray <rjray@blackperl.com>
-#               All Rights Reserved
+#   Copyright (c) 2000, 2001, 2002  Randy J. Ray <rjray@blackperl.com>
+#             (c) 2006, 2007  Alexey Tourbin <at@altlinux.org>
+#   All Rights Reserved
 #
 ###############################################################################
 #
-#   $Id: Database.pm,v 1.16 2001/03/08 06:12:32 rjray Exp $
-#
 #   Description:    The RPM::Database class provides access to the RPM database
 #                   as a tied hash, whose keys are taken as the names of
 #                   packages installed and whose values are RPM::Header
@@ -29,23 +28,22 @@ package RPM::Database;
 require 5.005;
 
 use strict;
-use vars qw($VERSION $revision %RPM $RPM);
+use vars qw($VERSION %RPM $RPM);
 use subs qw(new import);
 
-require RPM;
+require RPM; $VERSION = $RPM::VERSION;
 require RPM::Header;
 
-$VERSION = '0.30';
-$revision = do { my @r=(q$Revision: 1.16 $=~/\d+/g); sprintf "%d."."%02d"x$#r,@r };
-
 1;
 
 sub new
 {
     my $class = shift;
+    my $opts = shift;
     my %hash = ();
 
-    tie %hash, $class;
+    # The presence of $opts when empty is hard on the XS TIEHASH method
+    $opts ? tie(%hash, $class, $opts) : tie(%hash, $class);
 }
 
 ###############################################################################
@@ -160,6 +158,18 @@ hash reference, it can be used to call these methods via:
 
 =over
 
+=item new
+
+Creates a tied hash using a lexically-scoped hash table, then returns a
+reference to it (the return value of the C<tie> operation). This reference
+prevents the hash table from going out of scope. If a hash-reference of
+options is passed to this constructor, they are passed along to the tie of the
+hash. If a single scalar argument is passed, it is assumed to be an alternate
+database root to be used in opening the RPM database. The hash-reference
+currently only supports a single key, C<root>, which serves the same
+purpose. The hash-reference approach leaves open the possibilty of future
+options being added.
+
 =item init
 
 This causes a complete initialization of the RPM database. It must be run
@@ -245,8 +255,9 @@ subject to change in future releases.
 
 L<RPM>, L<RPM::Header>, L<perl>, L<rpm>
 
-=head1 AUTHOR
+=head1 AUTHORS
 
-Randy J. Ray <rjray@blackperl.com>
+Randy J. Ray <rjray@blackperl.com>,
+Alexey Tourbin <at@altlinux.org>.
 
 =cut
